

class DeviceGroup(object):
    """Generated from OpenAPI #/components/schemas/Device.DeviceGroup model

    An abstract container for emulated device containers  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - ports (list[str]): One or more port names that the emulated device containers will share
    - devices (list[Device]): An unordered list of 0..n emulated device containers
    """
    def __init__(self, name=None, ports=[], devices=[]):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(ports, (list, type(None))) is True:
            self.ports = ports
        else:
            raise TypeError('ports must be an instance of (list, type(None))')
        if isinstance(devices, (list, type(None))) is True:
            self.devices = devices
        else:
            raise TypeError('devices must be an instance of (list, type(None))')


class Device(object):
    """Generated from OpenAPI #/components/schemas/Device.Device model

    An abstract container for emulated devices  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - devices_per_port (Union[float, int]): The number of emulated devices that will be created on each port
    - ethernets (list[Ethernet]): An unordered list of 0..n emulated ethernet protocols
    - devices (list[Device]): An unordered list of 0..n emulated device containers
    - networks (list[Network]): An unordered list of 0..n emulated device containers
    """
    def __init__(self, name=None, devices_per_port=None, ethernets=[], devices=[], networks=[]):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(devices_per_port, (float, int, type(None))) is True:
            self.devices_per_port = devices_per_port
        else:
            raise TypeError('devices_per_port must be an instance of (float, int, type(None))')
        if isinstance(ethernets, (list, type(None))) is True:
            self.ethernets = ethernets
        else:
            raise TypeError('ethernets must be an instance of (list, type(None))')
        if isinstance(devices, (list, type(None))) is True:
            self.devices = devices
        else:
            raise TypeError('devices must be an instance of (list, type(None))')
        if isinstance(networks, (list, type(None))) is True:
            self.networks = networks
        else:
            raise TypeError('networks must be an instance of (list, type(None))')


class Ethernet(object):
    """Generated from OpenAPI #/components/schemas/Device.Ethernet model

    Emulated ethernet protocol  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - mac (Pattern): A container for emulated device property patterns
    - mtu (Pattern): A container for emulated device property patterns
    - vlans (list[Vlan]): List of vlans
    - ipv4 (Ipv4): Emulated ipv4 protocol
    - ipv6 (Ipv6): Emulated ipv6 protocol
    """
    def __init__(self, name=None, mac=None, mtu=None, vlans=[], ipv4=None, ipv6=None):
        from abstract_open_traffic_generator.device import Pattern
        from abstract_open_traffic_generator.device import Ipv4
        from abstract_open_traffic_generator.device import Ipv6
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(mac, (Pattern, type(None))) is True:
            self.mac = mac
        else:
            raise TypeError('mac must be an instance of (Pattern, type(None))')
        if isinstance(mtu, (Pattern, type(None))) is True:
            self.mtu = mtu
        else:
            raise TypeError('mtu must be an instance of (Pattern, type(None))')
        if isinstance(vlans, (list, type(None))) is True:
            self.vlans = vlans
        else:
            raise TypeError('vlans must be an instance of (list, type(None))')
        if isinstance(ipv4, (Ipv4, type(None))) is True:
            self.ipv4 = ipv4
        else:
            raise TypeError('ipv4 must be an instance of (Ipv4, type(None))')
        if isinstance(ipv6, (Ipv6, type(None))) is True:
            self.ipv6 = ipv6
        else:
            raise TypeError('ipv6 must be an instance of (Ipv6, type(None))')


class Pattern(object):
    """Generated from OpenAPI #/components/schemas/Device.Pattern model

    A container for emulated device property patterns  

    Args
    ----
    - choice (Union[str, list, Counter, Random]): TBD
    """
    _CHOICE_MAP = {
        'str': 'fixed',
        'list': 'list',
        'Counter': 'counter',
        'Random': 'random',
    }
    def __init__(self, choice=None):
        from abstract_open_traffic_generator.device import Counter
        from abstract_open_traffic_generator.device import Random
        if isinstance(choice, (str, list, Counter, Random)) is False:
            raise TypeError('choice must be of type: str, list, Counter, Random')
        self.__setattr__('choice', Pattern._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Pattern._CHOICE_MAP[type(choice).__name__], choice)


class Counter(object):
    """Generated from OpenAPI #/components/schemas/Device.Counter model

    An incrementing pattern  

    Args
    ----
    - start (str): TBD
    - step (str): TBD
    - up (Union[True, False]): TBD
    """
    def __init__(self, start=None, step=None, up=None):
        if isinstance(start, (str, type(None))) is True:
            self.start = start
        else:
            raise TypeError('start must be an instance of (str, type(None))')
        if isinstance(step, (str, type(None))) is True:
            self.step = step
        else:
            raise TypeError('step must be an instance of (str, type(None))')
        if isinstance(up, (bool, type(None))) is True:
            self.up = up
        else:
            raise TypeError('up must be an instance of (bool, type(None))')


class Decrement(object):
    """Generated from OpenAPI #/components/schemas/Device.Decrement model

    A decrementing pattern  

    Args
    ----
    - start (str): TBD
    - step (str): TBD
    """
    def __init__(self, start=None, step=None):
        if isinstance(start, (str, type(None))) is True:
            self.start = start
        else:
            raise TypeError('start must be an instance of (str, type(None))')
        if isinstance(step, (str, type(None))) is True:
            self.step = step
        else:
            raise TypeError('step must be an instance of (str, type(None))')


class Random(object):
    """Generated from OpenAPI #/components/schemas/Device.Random model

    A repeatable random range pattern  

    Args
    ----
    - min (str): TBD
    - max (str): TBD
    - step (Union[float, int]): TBD
    - seed (str): TBD
    """
    def __init__(self, min=None, max=None, step=None, seed=None):
        if isinstance(min, (str, type(None))) is True:
            self.min = min
        else:
            raise TypeError('min must be an instance of (str, type(None))')
        if isinstance(max, (str, type(None))) is True:
            self.max = max
        else:
            raise TypeError('max must be an instance of (str, type(None))')
        if isinstance(step, (float, int, type(None))) is True:
            self.step = step
        else:
            raise TypeError('step must be an instance of (float, int, type(None))')
        if isinstance(seed, (str, type(None))) is True:
            self.seed = seed
        else:
            raise TypeError('seed must be an instance of (str, type(None))')


class Vlan(object):
    """Generated from OpenAPI #/components/schemas/Device.Vlan model

    Emulated vlan protocol  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - tpid (Pattern): A container for emulated device property patterns
    - priority (Pattern): A container for emulated device property patterns
    - id (Pattern): A container for emulated device property patterns
    """
    def __init__(self, name=None, tpid=None, priority=None, id=None):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(tpid, (Pattern, type(None))) is True:
            self.tpid = tpid
        else:
            raise TypeError('tpid must be an instance of (Pattern, type(None))')
        if isinstance(priority, (Pattern, type(None))) is True:
            self.priority = priority
        else:
            raise TypeError('priority must be an instance of (Pattern, type(None))')
        if isinstance(id, (Pattern, type(None))) is True:
            self.id = id
        else:
            raise TypeError('id must be an instance of (Pattern, type(None))')


class Ipv4(object):
    """Generated from OpenAPI #/components/schemas/Device.Ipv4 model

    Emulated ipv4 protocol  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - address (Pattern): A container for emulated device property patterns
    - gateway (Pattern): A container for emulated device property patterns
    - prefix (Pattern): A container for emulated device property patterns
    - bgpv4 (Bgpv4): Emulated bgpv4 protocol
    """
    def __init__(self, name=None, address=None, gateway=None, prefix=None, bgpv4=None):
        from abstract_open_traffic_generator.device import Pattern
        from abstract_open_traffic_generator.device import Bgpv4
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(address, (Pattern, type(None))) is True:
            self.address = address
        else:
            raise TypeError('address must be an instance of (Pattern, type(None))')
        if isinstance(gateway, (Pattern, type(None))) is True:
            self.gateway = gateway
        else:
            raise TypeError('gateway must be an instance of (Pattern, type(None))')
        if isinstance(prefix, (Pattern, type(None))) is True:
            self.prefix = prefix
        else:
            raise TypeError('prefix must be an instance of (Pattern, type(None))')
        if isinstance(bgpv4, (Bgpv4, type(None))) is True:
            self.bgpv4 = bgpv4
        else:
            raise TypeError('bgpv4 must be an instance of (Bgpv4, type(None))')


class Bgpv4(object):
    """Generated from OpenAPI #/components/schemas/Device.Bgpv4 model

    Emulated bgpv4 protocol  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - as_number_2_byte (Pattern): A container for emulated device property patterns
    - dut_as_number_2_byte (Pattern): A container for emulated device property patterns
    - as_number_4_byte (Pattern): A container for emulated device property patterns
    - as_number_set_mode (Pattern): A container for emulated device property patterns
    - as_type (Union[IBGP, EBGP]): The type of BGP autonomous system. External BGP (EBGP) is used for BGP links between two or more autonomous systems. Internal BGP (IBGP) is used within a single autonomous system
    - hold_time_interval (Pattern): A container for emulated device property patterns
    - keep_alive_interval (Pattern): A container for emulated device property patterns
    - graceful_restart (Pattern): A container for emulated device property patterns
    - authentication (Pattern): A container for emulated device property patterns
    - ttl (Pattern): A container for emulated device property patterns
    - dut_ipv4_address (Pattern): A container for emulated device property patterns
    """
    def __init__(self, name=None, as_number_2_byte=None, dut_as_number_2_byte=None, as_number_4_byte=None, as_number_set_mode=None, as_type=None, hold_time_interval=None, keep_alive_interval=None, graceful_restart=None, authentication=None, ttl=None, dut_ipv4_address=None):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(as_number_2_byte, (Pattern, type(None))) is True:
            self.as_number_2_byte = as_number_2_byte
        else:
            raise TypeError('as_number_2_byte must be an instance of (Pattern, type(None))')
        if isinstance(dut_as_number_2_byte, (Pattern, type(None))) is True:
            self.dut_as_number_2_byte = dut_as_number_2_byte
        else:
            raise TypeError('dut_as_number_2_byte must be an instance of (Pattern, type(None))')
        if isinstance(as_number_4_byte, (Pattern, type(None))) is True:
            self.as_number_4_byte = as_number_4_byte
        else:
            raise TypeError('as_number_4_byte must be an instance of (Pattern, type(None))')
        if isinstance(as_number_set_mode, (Pattern, type(None))) is True:
            self.as_number_set_mode = as_number_set_mode
        else:
            raise TypeError('as_number_set_mode must be an instance of (Pattern, type(None))')
        if isinstance(as_type, (str, type(None))) is True:
            self.as_type = as_type
        else:
            raise TypeError('as_type must be an instance of (str, type(None))')
        if isinstance(hold_time_interval, (Pattern, type(None))) is True:
            self.hold_time_interval = hold_time_interval
        else:
            raise TypeError('hold_time_interval must be an instance of (Pattern, type(None))')
        if isinstance(keep_alive_interval, (Pattern, type(None))) is True:
            self.keep_alive_interval = keep_alive_interval
        else:
            raise TypeError('keep_alive_interval must be an instance of (Pattern, type(None))')
        if isinstance(graceful_restart, (Pattern, type(None))) is True:
            self.graceful_restart = graceful_restart
        else:
            raise TypeError('graceful_restart must be an instance of (Pattern, type(None))')
        if isinstance(authentication, (Pattern, type(None))) is True:
            self.authentication = authentication
        else:
            raise TypeError('authentication must be an instance of (Pattern, type(None))')
        if isinstance(ttl, (Pattern, type(None))) is True:
            self.ttl = ttl
        else:
            raise TypeError('ttl must be an instance of (Pattern, type(None))')
        if isinstance(dut_ipv4_address, (Pattern, type(None))) is True:
            self.dut_ipv4_address = dut_ipv4_address
        else:
            raise TypeError('dut_ipv4_address must be an instance of (Pattern, type(None))')


class Bgpv4RouteRange(object):
    """Generated from OpenAPI #/components/schemas/Device.Bgpv4RouteRange model

    Emulated bgpv4 route range  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - address (Pattern): A container for emulated device property patterns
    - prefix (Pattern): A container for emulated device property patterns
    - as_path (Pattern): A container for emulated device property patterns
    - next_hop_address (Pattern): A container for emulated device property patterns
    - aigp_metric (Pattern): A container for emulated device property patterns
    - atomic_aggregate (Pattern): A container for emulated device property patterns
    """
    def __init__(self, name=None, address=None, prefix=None, as_path=None, next_hop_address=None, aigp_metric=None, atomic_aggregate=None):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(address, (Pattern, type(None))) is True:
            self.address = address
        else:
            raise TypeError('address must be an instance of (Pattern, type(None))')
        if isinstance(prefix, (Pattern, type(None))) is True:
            self.prefix = prefix
        else:
            raise TypeError('prefix must be an instance of (Pattern, type(None))')
        if isinstance(as_path, (Pattern, type(None))) is True:
            self.as_path = as_path
        else:
            raise TypeError('as_path must be an instance of (Pattern, type(None))')
        if isinstance(next_hop_address, (Pattern, type(None))) is True:
            self.next_hop_address = next_hop_address
        else:
            raise TypeError('next_hop_address must be an instance of (Pattern, type(None))')
        if isinstance(aigp_metric, (Pattern, type(None))) is True:
            self.aigp_metric = aigp_metric
        else:
            raise TypeError('aigp_metric must be an instance of (Pattern, type(None))')
        if isinstance(atomic_aggregate, (Pattern, type(None))) is True:
            self.atomic_aggregate = atomic_aggregate
        else:
            raise TypeError('atomic_aggregate must be an instance of (Pattern, type(None))')


class Ipv6(object):
    """Generated from OpenAPI #/components/schemas/Device.Ipv6 model

    Emulated ipv6 protocol  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - address (Pattern): A container for emulated device property patterns
    - gateway (Pattern): A container for emulated device property patterns
    - prefix (Pattern): A container for emulated device property patterns
    - manual_gateway_mac (Pattern): A container for emulated device property patterns
    """
    def __init__(self, name=None, address=None, gateway=None, prefix=None, manual_gateway_mac=None):
        from abstract_open_traffic_generator.device import Pattern
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(address, (Pattern, type(None))) is True:
            self.address = address
        else:
            raise TypeError('address must be an instance of (Pattern, type(None))')
        if isinstance(gateway, (Pattern, type(None))) is True:
            self.gateway = gateway
        else:
            raise TypeError('gateway must be an instance of (Pattern, type(None))')
        if isinstance(prefix, (Pattern, type(None))) is True:
            self.prefix = prefix
        else:
            raise TypeError('prefix must be an instance of (Pattern, type(None))')
        if isinstance(manual_gateway_mac, (Pattern, type(None))) is True:
            self.manual_gateway_mac = manual_gateway_mac
        else:
            raise TypeError('manual_gateway_mac must be an instance of (Pattern, type(None))')


class Network(object):
    """Generated from OpenAPI #/components/schemas/Device.Network model

    An abstract container for an emulated network devices  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - network_devices_per_port (Union[float, int]): The number of emulated network devices that will be created on each port
    - flow_link (str): Identifies which object in another container is the next hop from this container. The name cannot be one of the names in this networks container. An empty value indicates there is no flow link other than the default specified by the implementation
    - choice (Union[Bgpv4RouteRange]): The type of emulated network devices in the container
    """
    _CHOICE_MAP = {
        'Bgpv4RouteRange': 'bgpv4_route_range',
    }
    def __init__(self, name=None, network_devices_per_port=None, flow_link=None, choice=None):
        from abstract_open_traffic_generator.device import Bgpv4RouteRange
        if isinstance(choice, (Bgpv4RouteRange)) is False:
            raise TypeError('choice must be of type: Bgpv4RouteRange')
        self.__setattr__('choice', Network._CHOICE_MAP[type(choice).__name__])
        self.__setattr__(Network._CHOICE_MAP[type(choice).__name__], choice)
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(network_devices_per_port, (float, int, type(None))) is True:
            self.network_devices_per_port = network_devices_per_port
        else:
            raise TypeError('network_devices_per_port must be an instance of (float, int, type(None))')
        if isinstance(flow_link, (str, type(None))) is True:
            self.flow_link = flow_link
        else:
            raise TypeError('flow_link must be an instance of (str, type(None))')





class Port(object):
    """Generated from OpenAPI #/components/schemas/Port.Port model

    An abstract test port  

    Args
    ----
    - name (str): Unique name of an object that is the primary key for objects found in arrays
    - location (str): The location of a test port. It is the endpoint where packets will emit from. Test port locations can be the following:
        physical appliance with multiple ports
        physical chassis with multiple cards and ports
        local interface
        virtual machine, docker container, kubernetes cluster The test port location format is implementation specific. Use the /results API to determine what formats the implementation supports for the location property
    - link_state (Union[up, down]): The configured link state of the port. Compare the actual state vs the configured state by using the /results API
    - capture_state (Union[start, stop]): The configured capture state of the port. Compare the actual state vs the configured state by using the /results API
    """
    def __init__(self, name=None, location=None, link_state=None, capture_state=None):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(location, (str, type(None))) is True:
            self.location = location
        else:
            raise TypeError('location must be an instance of (str, type(None))')
        if isinstance(link_state, (str, type(None))) is True:
            self.link_state = link_state
        else:
            raise TypeError('link_state must be an instance of (str, type(None))')
        if isinstance(capture_state, (str, type(None))) is True:
            self.capture_state = capture_state
        else:
            raise TypeError('capture_state must be an instance of (str, type(None))')



import pytest
from abstract_open_traffic_generator import *


def test_connect():
    # api = Api()
    # try:
    #     api.connect()
    #     assert('Incorrect behavior')
    # except NotImplementedError:
    #     pass
    pass


def test_sate_config():
    # api = Api()
    # config = Config()
    # try:
    #     api.control(payload=config)
    #     assert('Incorrect behavior')
    # except NotImplementedError:
    #     pass
    pass


if __name__ == '__main__':
    pytest.main(['-s', __file__])





class Config(object):
    """Generated from OpenAPI #/components/schemas/Config.Config model

    A container for all models that are part of the configuration  

    Args
    ----
    - ports (list[Port]): The ports that will be configured on the traffic generator
    - devices (list[DeviceGroup]): The devices that will be configured on the traffic generator
    - flows (list[Flow]): The flows that will be configured on the traffic generator
    - captures (list[Capture]): The captures that will be configured on the traffic generator
    """
    def __init__(self, ports=[], devices=[], flows=[], captures=[]):
        if isinstance(ports, (list, type(None))) is True:
            self.ports = ports
        else:
            raise TypeError('ports must be an instance of (list, type(None))')
        if isinstance(devices, (list, type(None))) is True:
            self.devices = devices
        else:
            raise TypeError('devices must be an instance of (list, type(None))')
        if isinstance(flows, (list, type(None))) is True:
            self.flows = flows
        else:
            raise TypeError('flows must be an instance of (list, type(None))')
        if isinstance(captures, (list, type(None))) is True:
            self.captures = captures
        else:
            raise TypeError('captures must be an instance of (list, type(None))')





class Request(object):
    """Generated from OpenAPI #/components/schemas/Result.Request model

    The result request to the traffic generator   

    Args
    ----
    - result_type (Union[state, location, ports, flows]): TBD
    """
    def __init__(self, result_type=None):
        if isinstance(result_type, (str, type(None))) is True:
            self.result_type = result_type
        else:
            raise TypeError('result_type must be an instance of (str, type(None))')


class Response(object):
    """Generated from OpenAPI #/components/schemas/Result.Response model

    The result response from the traffic generator   

    Args
    ----
    - state (State): TBD
    - location (Location): Location result. Used to find out the possible types of location formats supported by an implementation. Implementations will return a description of the location format along with the regex format that will be used to validate the location input on the port object
    - ports (Port): TBD
    - flows (Flow): TBD
    """
    def __init__(self, state=None, location=None, ports=None, flows=None):
        from abstract_open_traffic_generator.result import State
        from abstract_open_traffic_generator.result import Location
        from abstract_open_traffic_generator.result import Port
        from abstract_open_traffic_generator.result import Flow
        if isinstance(state, (State, type(None))) is True:
            self.state = state
        else:
            raise TypeError('state must be an instance of (State, type(None))')
        if isinstance(location, (Location, type(None))) is True:
            self.location = location
        else:
            raise TypeError('location must be an instance of (Location, type(None))')
        if isinstance(ports, (Port, type(None))) is True:
            self.ports = ports
        else:
            raise TypeError('ports must be an instance of (Port, type(None))')
        if isinstance(flows, (Flow, type(None))) is True:
            self.flows = flows
        else:
            raise TypeError('flows must be an instance of (Flow, type(None))')


class State(object):
    """Generated from OpenAPI #/components/schemas/Result.State model

    TBD  

    Args
    ----
    - state_transitions (Union[success, errored, transitioning]): TBD
    - transitions (Union[float, int]): Indicates the current total number of state transitions
    - errors (Union[float, int]): Indicates the current total number of state errors
    - details (list[StateDetail]): TBD
    """
    def __init__(self, state_transitions=None, transitions=None, errors=None, details=[]):
        if isinstance(state_transitions, (str, type(None))) is True:
            self.state_transitions = state_transitions
        else:
            raise TypeError('state_transitions must be an instance of (str, type(None))')
        if isinstance(transitions, (float, int, type(None))) is True:
            self.transitions = transitions
        else:
            raise TypeError('transitions must be an instance of (float, int, type(None))')
        if isinstance(errors, (float, int, type(None))) is True:
            self.errors = errors
        else:
            raise TypeError('errors must be an instance of (float, int, type(None))')
        if isinstance(details, (list, type(None))) is True:
            self.details = details
        else:
            raise TypeError('details must be an instance of (list, type(None))')


class StateDetail(object):
    """Generated from OpenAPI #/components/schemas/Result.StateDetail model

    TBD  

    Args
    ----
    - name (str): The unique name of an object in the configuration
    - configured (str): The configured state of the named object
    - current (str): The current state of the named object
    - message (str): Detailed transition or error information
    """
    def __init__(self, name=None, configured=None, current=None, message=None):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(configured, (str, type(None))) is True:
            self.configured = configured
        else:
            raise TypeError('configured must be an instance of (str, type(None))')
        if isinstance(current, (str, type(None))) is True:
            self.current = current
        else:
            raise TypeError('current must be an instance of (str, type(None))')
        if isinstance(message, (str, type(None))) is True:
            self.message = message
        else:
            raise TypeError('message must be an instance of (str, type(None))')


class Location(object):
    """Generated from OpenAPI #/components/schemas/Result.Location model

    Location result  
    Used to find out the possible types of location formats supported by an implementation  
    Implementations will return a description of the location format along with the regex format that will be used to validate the location input on the port object  

    Args
    ----
    - description (str): The description of the location format
    - format (str): The regex format of the location
    """
    def __init__(self, description=None, format=None):
        if isinstance(description, (str, type(None))) is True:
            self.description = description
        else:
            raise TypeError('description must be an instance of (str, type(None))')
        if isinstance(format, (str, type(None))) is True:
            self.format = format
        else:
            raise TypeError('format must be an instance of (str, type(None))')


class Port(object):
    """Generated from OpenAPI #/components/schemas/Result.Port model

    TBD  

    Args
    ----
    - name (str): The name of a configured port
    - frames_tx (Union[float, int]): The current total number of frames transmitted
    - frames_rx (Union[float, int]): The current total number of valid frames received
    - bytes_tx (Union[float, int]): The current total number of bytes transmitted
    - bytes_rx (Union[float, int]): The current total number of valid bytes received
    - frames_tx_rate (Union[float, int]): The current rate of frames transmitted
    - frames_rx_rate (Union[float, int]): The current rate of valid frames received
    - data_integrity_errors (Union[float, int]): The current total number of data integrity errors
    - counters (list[None]): A map of unique names of PortCounter objects added to Port objects and the corresponding count values
    """
    def __init__(self, name=None, frames_tx=None, frames_rx=None, bytes_tx=None, bytes_rx=None, frames_tx_rate=None, frames_rx_rate=None, data_integrity_errors=None, counters=[]):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(frames_tx, (float, int, type(None))) is True:
            self.frames_tx = frames_tx
        else:
            raise TypeError('frames_tx must be an instance of (float, int, type(None))')
        if isinstance(frames_rx, (float, int, type(None))) is True:
            self.frames_rx = frames_rx
        else:
            raise TypeError('frames_rx must be an instance of (float, int, type(None))')
        if isinstance(bytes_tx, (float, int, type(None))) is True:
            self.bytes_tx = bytes_tx
        else:
            raise TypeError('bytes_tx must be an instance of (float, int, type(None))')
        if isinstance(bytes_rx, (float, int, type(None))) is True:
            self.bytes_rx = bytes_rx
        else:
            raise TypeError('bytes_rx must be an instance of (float, int, type(None))')
        if isinstance(frames_tx_rate, (float, int, type(None))) is True:
            self.frames_tx_rate = frames_tx_rate
        else:
            raise TypeError('frames_tx_rate must be an instance of (float, int, type(None))')
        if isinstance(frames_rx_rate, (float, int, type(None))) is True:
            self.frames_rx_rate = frames_rx_rate
        else:
            raise TypeError('frames_rx_rate must be an instance of (float, int, type(None))')
        if isinstance(data_integrity_errors, (float, int, type(None))) is True:
            self.data_integrity_errors = data_integrity_errors
        else:
            raise TypeError('data_integrity_errors must be an instance of (float, int, type(None))')
        if isinstance(counters, (list, type(None))) is True:
            self.counters = counters
        else:
            raise TypeError('counters must be an instance of (list, type(None))')


class Flow(object):
    """Generated from OpenAPI #/components/schemas/Result.Flow model

    TBD  

    Args
    ----
    - name (str): The name of a configured flow
    - port_tx (str): The name of a configured port
    - port_rx (str): The name of a configured port
    - frames_tx (Union[float, int]): The current total number of frames transmitted
    - frames_rx (Union[float, int]): The current total number of valid frames received
    - bytes_tx (Union[float, int]): The current total number of bytes transmitted
    - bytes_rx (Union[float, int]): The current total number of valid bytes received
    - frames_tx_rate (Union[float, int]): The current rate of frames transmitted
    - frames_rx_rate (Union[float, int]): The current rate of valid frames received
    - loss (Union[float, int]): The percentage of lost frames
    - group_by (None): A runtime map of field name to result value The name comes from the flow.packet.header.group_by property
    """
    def __init__(self, name=None, port_tx=None, port_rx=None, frames_tx=None, frames_rx=None, bytes_tx=None, bytes_rx=None, frames_tx_rate=None, frames_rx_rate=None, loss=None, group_by=None):
        if isinstance(name, (str, type(None))) is True:
            self.name = name
        else:
            raise TypeError('name must be an instance of (str, type(None))')
        if isinstance(port_tx, (str, type(None))) is True:
            self.port_tx = port_tx
        else:
            raise TypeError('port_tx must be an instance of (str, type(None))')
        if isinstance(port_rx, (str, type(None))) is True:
            self.port_rx = port_rx
        else:
            raise TypeError('port_rx must be an instance of (str, type(None))')
        if isinstance(frames_tx, (float, int, type(None))) is True:
            self.frames_tx = frames_tx
        else:
            raise TypeError('frames_tx must be an instance of (float, int, type(None))')
        if isinstance(frames_rx, (float, int, type(None))) is True:
            self.frames_rx = frames_rx
        else:
            raise TypeError('frames_rx must be an instance of (float, int, type(None))')
        if isinstance(bytes_tx, (float, int, type(None))) is True:
            self.bytes_tx = bytes_tx
        else:
            raise TypeError('bytes_tx must be an instance of (float, int, type(None))')
        if isinstance(bytes_rx, (float, int, type(None))) is True:
            self.bytes_rx = bytes_rx
        else:
            raise TypeError('bytes_rx must be an instance of (float, int, type(None))')
        if isinstance(frames_tx_rate, (float, int, type(None))) is True:
            self.frames_tx_rate = frames_tx_rate
        else:
            raise TypeError('frames_tx_rate must be an instance of (float, int, type(None))')
        if isinstance(frames_rx_rate, (float, int, type(None))) is True:
            self.frames_rx_rate = frames_rx_rate
        else:
            raise TypeError('frames_rx_rate must be an instance of (float, int, type(None))')
        if isinstance(loss, (float, int, type(None))) is True:
            self.loss = loss
        else:
            raise TypeError('loss must be an instance of (float, int, type(None))')
        if isinstance(group_by, None) is True:
            self.group_by = group_by
        else:
            raise TypeError('group_by must be an instance of None')
